multiformats.multihash
======================

.. automodule:: multiformats.multihash

Multihash
---------

.. autoclass:: multiformats.multihash.Multihash
    :members:

digest
------

.. autofunction:: multiformats.multihash.digest

exists
------

.. autofunction:: multiformats.multihash.exists

from_digest
-----------

.. autofunction:: multiformats.multihash.from_digest

get
---

.. autofunction:: multiformats.multihash.get

is_implemented
--------------

.. autofunction:: multiformats.multihash.is_implemented

unwrap
------

.. autofunction:: multiformats.multihash.unwrap

unwrap_raw
----------

.. autofunction:: multiformats.multihash.unwrap_raw

wrap
----

.. autofunction:: multiformats.multihash.wrap
